@@ -20,7 +20,7 @@
 
 #include <glib.h>
 #include <gtk/gtk.h>
-#include <libindicator/indicator-object.h>
+#include <libayatana-indicator/indicator-object.h>
 
 #include "indicator-config.h"
 #include "indicator-box.h"
