@@ -24,7 +24,7 @@
  */
 
 
-#define INDICATOR_SERVICE_DIR "/usr/share/unity/indicators"
+#define INDICATOR_SERVICE_DIR "/usr/share/ayatana/indicators"
 
 
 #ifdef HAVE_CONFIG_H
@@ -37,9 +37,9 @@
 #include <gtk/gtk.h>
 #include <libxfce4util/libxfce4util.h>
 #include <libxfce4panel/xfce-panel-plugin.h>
-#include <libindicator/indicator-object.h>
-#ifdef HAVE_LIBINDICATOR_INDICATOR_NG_H
-#include <libindicator/indicator-ng.h>
+#include <libayatana-indicator/indicator-object.h>
+#ifdef HAVE_LIBAYATANA_INDICATOR_INDICATOR_NG_H
+#include <libayatana-indicator/indicator-ng.h>
 #endif
 
 #include "indicator.h"
@@ -48,7 +48,7 @@
 #include "indicator-dialog.h"
 
 #ifdef HAVE_IDO
-#include <libido/libido.h>
+#include <libayatana-ido/libayatana-ido.h>
 #endif
 
 /* prototypes */
@@ -65,7 +65,7 @@ static gboolean         indicator_load_indicator                   (IndicatorPlu
                                                                     const gchar           *name);
 static gboolean         indicator_load_module                      (IndicatorPlugin       *indicator,
                                                                     const gchar           *name);
-#ifdef HAVE_LIBINDICATOR_INDICATOR_NG_H
+#ifdef HAVE_LIBAYATANA_INDICATOR_INDICATOR_NG_H
 static gboolean         indicator_load_service                     (IndicatorPlugin       *indicator,
                                                                     const gchar           *name);
 static void             indicator_load_services                    (IndicatorPlugin       *indicator);
@@ -124,11 +124,13 @@ indicator_class_init (IndicatorPluginClass *klass)
 static void
 indicator_init (IndicatorPlugin *indicator)
 {
+#ifdef G_ENABLE_DEBUG
   /* Indicators print a lot of warnings. By default, "wrapper"
      makes them critical, so the plugin "crashes" when run as an external
      plugin but not internal one (loaded by "xfce4-panel" itself).
      The following lines makes only g_error critical. */
   g_log_set_always_fatal (G_LOG_LEVEL_ERROR);
+#endif
 
   indicator->indicator_count = 0;
   indicator->buttonbox       = NULL;
@@ -154,8 +156,6 @@ indicator_free (XfcePanelPlugin *plugin)
 static void
 indicator_show_about (XfcePanelPlugin *plugin)
 {
-   GdkPixbuf *icon;
-
    const gchar *auth[] =
      {
        "Mark Trompell <mark@foresightlinux.org>",
@@ -170,19 +170,15 @@ indicator_show_about (XfcePanelPlugin *plugin)
 
    g_return_if_fail (XFCE_IS_INDICATOR_PLUGIN (plugin));
 
-   icon = xfce_panel_pixbuf_from_source("xfce4-indicator-plugin", NULL, 32);
    gtk_show_about_dialog(NULL,
-                         "logo", icon,
+                         "logo-icon-name", "xfce4-indicator-plugin",
                          "license", xfce_get_license_text (XFCE_LICENSE_TEXT_GPL),
                          "version", PACKAGE_VERSION,
                          "program-name", PACKAGE_NAME,
                          "comments", _("Provides a panel area for Unity indicators. Indicators allow applications and system services to display their status and interact with the user."),
                          "website", "https://docs.xfce.org/panel-plugins/xfce4-indicator-plugin",
-                         "copyright", _("Copyright (c) 2009-2013\n"),
+                         "copyright", "Copyright \302\251 2009-2023 The Xfce development team",
                          "authors", auth, NULL);
-
-   if(icon)
-     g_object_unref(G_OBJECT(icon));
 }
 
 
@@ -275,7 +271,6 @@ static void
 indicator_construct (XfcePanelPlugin *plugin)
 {
   IndicatorPlugin  *indicator = XFCE_INDICATOR_PLUGIN (plugin);
-  GtkWidget        *label;
 
   #ifdef HAVE_IDO
   ido_init();
@@ -308,7 +303,7 @@ indicator_construct (XfcePanelPlugin *plugin)
 
   /* load 'em */
   indicator_load_modules (indicator);
-#ifdef HAVE_LIBINDICATOR_INDICATOR_NG_H
+#ifdef HAVE_LIBAYATANA_INDICATOR_INDICATOR_NG_H
   indicator_load_services (indicator);
 #endif
 }
@@ -410,7 +405,7 @@ indicator_load_module (IndicatorPlugin *indicator,
     return FALSE;
 
 #ifdef DISABLE_APPLICATION
-  if (!g_strcmp0 (name, "libapplication.so"))
+  if (!g_strcmp0 (name, "libayatana-application.so"))
     return FALSE;
 #endif
 
@@ -423,7 +418,7 @@ indicator_load_module (IndicatorPlugin *indicator,
   return indicator_load_indicator (indicator, io, name);
 }
 
-#ifdef HAVE_LIBINDICATOR_INDICATOR_NG_H
+#ifdef HAVE_LIBAYATANA_INDICATOR_INDICATOR_NG_H
 static gboolean
 indicator_load_service (IndicatorPlugin *indicator,
                         const gchar     *name)
